#
# spec file for package python3-img-proof
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without test
Name:           python3-img-proof
Version:        5.0.0
Release:        bp153.1.18
Summary:        Command line and API for testing custom images
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/SUSE-Enceladus/img-proof
Source:         https://files.pythonhosted.org/packages/source/i/img-proof/img-proof-%{version}.tar.gz
BuildRequires:  python3-PyYAML
BuildRequires:  python3-azure-common
BuildRequires:  python3-azure-mgmt-compute
BuildRequires:  python3-azure-mgmt-network
BuildRequires:  python3-azure-mgmt-resource
BuildRequires:  python3-boto3
BuildRequires:  python3-certifi
BuildRequires:  python3-click
BuildRequires:  python3-click-man
BuildRequires:  python3-cryptography
BuildRequires:  python3-devel
BuildRequires:  python3-google-api-python-client
BuildRequires:  python3-google-auth
BuildRequires:  python3-oci-sdk
BuildRequires:  python3-paramiko
BuildRequires:  python3-pycryptodome
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
BuildRequires:  python3-testinfra
%if %{with test}
BuildRequires:  python3-coverage
BuildRequires:  python3-pytest-cov
%endif
Requires:       python3-PyYAML
Requires:       python3-azure-common
Requires:       python3-azure-mgmt-compute
Requires:       python3-azure-mgmt-network
Requires:       python3-azure-mgmt-resource
Requires:       python3-boto3
Requires:       python3-certifi
Requires:       python3-click
Requires:       python3-cryptography
Requires:       python3-google-api-python-client
Requires:       python3-google-auth
Requires:       python3-oci-sdk
Requires:       python3-paramiko
Requires:       python3-pycryptodome
Requires:       python3-pytest
Requires:       python3-testinfra
BuildArch:      noarch
Obsoletes:      python3-ipa < 5.0.0

%description
img-proof provides a command line utility to test images in
the Public Cloud (AWS, Azure, GCE, etc.).

%package tests
Summary:        Infrastructure tests for img-proof
Group:          Development/Languages/Python
Requires:       python3-susepubliccloudinfo
PreReq:         python3-img-proof = %{version}
Obsoletes:      python3-ipa-tests < 5.0.0

%description tests
Directory of infrastructure tests for testing images.

%prep
%setup -q -n img-proof-%{version}

%build
python3 setup.py build
mkdir -p man/man1
python3 setup.py --command-packages=click_man.commands man_pages --target man/man1

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d -m 755 %{buildroot}/%{_mandir}/man1
install -m 644 man/man1/*.1 %{buildroot}/%{_mandir}/man1

install -d -m 755 %{buildroot}%{_prefix}
cp -r usr/* %{buildroot}%{_prefix}/

%check
%if %{with test}
export LC_ALL=en_US.utf-8
export LANG=en_US.utf-8
python3 -m pytest --cov=img_proof --ignore=tests/data --ignore=usr
%endif

%files
%defattr(-,root,root)
%license LICENSE
%doc CHANGES.md CONTRIBUTING.md README.md
%{_mandir}/man1/*
%{_bindir}/img-proof
%{python3_sitelib}/*

%files tests
%defattr(-,root,root)
%dir %{_datadir}/lib
%dir %{_datadir}/lib/img_proof
%{_datadir}/lib/img_proof/*

%changelog
* Wed May 20 2020 Sean Marlow <sean.marlow@suse.com>
- Update spec to fix build requires in with test clause.
* Tue Apr 21 2020 Sean Marlow <sean.marlow@suse.com>
- Update to v5.0.0 (2020-04-21)
  + Migrate GCE to Google API.
* Tue Mar 10 2020 Sean Marlow <sean.marlow@suse.com>
- Update to v4.8.1 (2020-03-10)
  + Fix bug and check both CLI output versions for single and
    double quote.
* Tue Mar 10 2020 Sean Marlow <sean.marlow@suse.com>
- Update to v4.8.0 (2020-03-10)
  + Attempt to cleanup instance if error during launch.
  + Add distro refresh option.
  + Use systemctl to check guestregister status.
  + Log only to base logger.
  + Handle HPC on-demand repos.
  + Add timestamp to file log handler.
* Tue Feb 18 2020 Sean Marlow <sean.marlow@suse.com>
- Update to v4.7.0 (2020-02-18)
  + Add list of 15-SP2 repos to SLES on-demand test.
  + Cleanup spec file.
* Tue Jan 21 2020 Sean Marlow <sean.marlow@suse.com>
- Update to v4.6.0 (2020-01-21)
  + Implement Oracle Cloud class (oci).
  + Edit sap license test to handle 12SP5.
  + Skip kernel test if not a latest image version.
  + Generate man pages in build with click-man.
* Mon Oct 28 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v4.5.1 (2019-10-28)
  + Use sudo for registration command which requires root
    privilege.
* Fri Oct 25 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v4.5.0 (2019-10-25)
  + Use registerutils functions to check registration.
* Mon Oct 14 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v4.4.0 (2019-10-14)
  + Remove region filter from smt registration test.
* Wed Aug 21 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v4.3.1 (2019-08-21)
  + Cleanup smt registration test.
  + Remove azure regions map.
  + Update get_smt_servers to not filter type.
* Tue Aug 13 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v4.3.0 (2019-08-13)
  + Update sles repos test for rmt.
  + Move get user data method to base class.
  + Add repos for sles12-sp5.
  + Print serial console output to log.
  + Add case for checking kernel config version.
* Thu Jul 18 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v4.2.1 (2019-07-18)
  + Consider location restrictions retryable in GCE.
  + Wait longer on soft reboot.
  + Add test for azure launch exception.
- Update to v4.2.0 (2019-07-16)
  + Remove support for py3.4.
  + Use the "baseproduct" link as indicator of the SLES product.
  + Indicate retryable error (GCE only).
* Mon Jul  1 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v4.1.1 (2019-07-01)
  + Run reboot in background process.
  + Make tox env work with python3.7.
* Thu Jun  6 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v4.1.0 (2019-06-06)
  + Make license test fixture generic.
  + Fix Leap license test for 15.1.
* Thu May 30 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v4.0.0 (2019-05-30).
  + Rename ipa to img-proof.
  + Clear ssh cache at start of module.
  + Move set_distro to beginning of method.
  + Attempt to cleanup instance on ssh fail.
  + Echo log file if results file provided.
